(function() {
	//オーディオ生成用オブジェクト
	var media = null;
	// 再生位置
	var mediaTimer = null;
	// 音量
	var volume = 50;

	// FileSystemに記録
	function requestFS(fileSystem) {
		fileSystem.root.getFile("recordMedia.m4a", {create: true, exclusive: false}, getFileEntrySuccess, getFileEntryError);
	}

	// FileSystemエラー処理
	function onErrorFS(error) {
		var dump = "ファイルシステムがエラーが発生しました。";
		dump += "code:" + error.code + "\n";
		document.getElementById("dumpAreaMedia").value = dump;
	}

	// ファイル取得成功時のコールバック処理
	function getFileEntrySuccess(entry) {
		var dump = "ファイル取得に成功しました。\n";
		document.getElementById("dumpAreaMedia").value = dump;

		// Mediaオブジェクト作成
		media = new Media(entry.fullPath, onNewMediaSuccess, onNewMediaError);
		// 録音開始
		media.startRecord();
	}

	//ファイル取得失敗時のコールバック処理
	function getFileEntryError(error) {
		var dump = "ファイル取得に失敗しました。\n";
		dump += "code:" + error.code + "\n";
		document.getElementById("dumpAreaMedia").value = dump;
	}

	// Mediaオブジェクト作成成功時のコールバック処理
	function onNewMediaSuccess() {
		var dump = "録音開始に成功しました。\n";
		document.getElementById("dumpAreaMedia").value = dump;
	}

	// Mediaオブジェクト作成失敗時のコールバック処理
	function onNewMediaError(error) {
		var dump = "録音開始に失敗しました。\n";
		dump += "code:" + error.code + "\n";
		document.getElementById("dumpAreaMedia").value = dump;
	}

	// 録音を停止する
	function stopRecord() {
		if (media) {
			media.stopRecord();
			var dump = "録音を停止しました。\n";
			document.getElementById("dumpAreaMedia").value = dump;
		}
	}

	// 再生を開始する
	function startPlay() {
		if (media) {
			media.setVolume(volume);
			media.play();
			getCurrentPosition();
			var dump = "再生を開始しました。\n";
			document.getElementById("dumpAreaMedia").value = dump;
		}
	}

	// 再生を開始する(バックグラウンドでも継続)
	function startPlayBg() {
		if (media) {
			media.setVolume(volume);
			media.playBackground();
			getCurrentPosition();
			var dump = "バックグラウンド再生を開始しました。\n";
			document.getElementById("dumpAreaMedia").value = dump;
		}
	}

	// 再生を停止する
	function stopPlay() {
		if (media) {
			if (mediaTimer) {
				clearInterval(mediaTimer);
				mediaTimer = null;
			}
			media.stop();
			// リソースを解放する場合
			// media.release();
			var dump = "再生を停止しました。\n";
			document.getElementById("dumpAreaMedia").value = dump;
		}
	}

	// 再生を一時停止する
	function pausePlay() {
		if (media) {
			media.pause();
			var dump = "再生を一時停止しました。\n";
			document.getElementById("dumpAreaMedia").value = dump;
		}
	}

	// 音量を高にする
	function volumeUp() {
		if (media) {
			volume += 10;
			media.setVolume(volume);
			var dump = "音量：" + volume + "\n";
			document.getElementById("dumpAreaMedia").value = dump;
		}
	}

	// 音量を低にする
	function volumeDown() {
		if (media) {
			volume -= 10;
			media.setVolume(volume);
			var dump = "音量：" + volume + "\n";
			document.getElementById("dumpAreaMedia").value = dump;
		}
	}

	// メディアファイルの再生位置を取得
	function getCurrentPosition() {
		// 1秒ごとに再生位置を取得
		mediaTimer = setInterval(function () {
			media.getCurrentPosition(
				function (position) {
					if (position > -1) {
						var dump = "再生位置：" + Math.round(position) + " sec\n";
						document.getElementById("dumpAreaMedia").value = dump;
					}
				},
				function (error) {
					var dump = "再生位置の取得に失敗しました。\n";
					dump += "code:" + error + "\n";
					document.getElementById("dumpAreaMedia").value = dump;
				}
			);
		}, 1000);
	}

	// メディアファイルの再生時間を取得
	function getDuration() {
		if (media) {
			// メディアファイルの再生時間（秒）を取得
			var counter = 0;
			var timerDur = setInterval(function() {
				counter = counter + 100;
				if (counter > 2000) {
					clearInterval(timerDur);
				}
				var dur = media.getDuration();
				if (dur > 0) {
					clearInterval(timerDur);
					var dump = "再生時間：" + Math.round(dur) + " sec\n";
					document.getElementById("dumpAreaMedia").value =dump;
				}
			}, 100);
		}
	}

	/********************* イベント登録 *********************/
	document.addEventListener("deviceready", function() {
		// 「録音開始」ボタン押下処理
		document.getElementById("recordStartBtn").addEventListener("touchend", function() {
			applican.requestFileSystem(LocalFileSystem.PERSISTENT, 0, requestFS, onErrorFS);
		}, false);
		// 「録音停止」ボタン押下処理
		document.getElementById("recordStopBtn").addEventListener("touchend", function() {
			stopRecord();
		}, false);
		// 「再生開始」ボタン押下処理
		document.getElementById("mediaPlayBtn").addEventListener("touchend", function() {
			startPlay();
		}, false);
		// 「バックグラウンド再生開始」ボタン押下処理
		document.getElementById("mediaPlayBgBtn").addEventListener("touchend", function() {
			startPlayBg();
		}, false);
		// 「一時停止」ボタン押下処理
		document.getElementById("mediaPauseBtn").addEventListener("touchend", function() {
			pausePlay();
		}, false);
		// 「再生停止」ボタン押下処理
		document.getElementById("mediaStopBtn").addEventListener("touchend", function() {
			stopPlay();
		}, false);
		// 「音量アップ」ボタン押下処理
		document.getElementById("volumeUpBtn").addEventListener("touchend", function() {
			volumeUp();
		}, false);
		// 「音量ダウン」ボタン押下処理
		document.getElementById("volumeDownBtn").addEventListener("touchend", function() {
			volumeDown();
		}, false);
		// 「再生時間取得」ボタン押下処理
		document.getElementById("getDurationBtn").addEventListener("touchend", function() {
			getDuration();
		}, false);
	}, false);
})();
